# Introduction
Donald Mango (1963 - 2022) was an actuary who made several notable contributions to the actuarial profession. Aspring candidates will recognize his name as he was the author of several papers that are part of the examinations that must be taken to achieve fellowsihp.

Mango is a Python package that aims to implement his ideas from the papers he wrote throughout his career.

# Papers

- [Capital Tranching: A RAROC Approach to Assessing Reinsurance Cost Effectiveness](https://www.casact.org/abstract/capital-tranching-raroc-approach-assessing-reinsurance-cost-effectiveness)
- [Applying Actuarial Techniques in Operational Risk Modeling](https://www.casact.org/abstract/applying-actuarial-techniques-operational-risk-modeling)
- [Insurance Capital as a Shared Asset](https://www.casact.org/abstract/insurance-capital-shared-asset)
- [A Method of Implementing Myers-Read Capital Allocation in Simulation](https://www.casact.org/abstract/method-implementing-myers-read-capital-allocation-simulation)
- [Capital Consumption: An Alternative Methodology for Pricing Reinsurance](https://www.casact.org/abstract/capital-consumption-alternative-methodology-pricing-reinsurance)
- [A Risk Charge Calculation Based on Conditional Probability](https://www.casact.org/abstract/risk-charge-calculation-based-conditional-probability)
- [Dependence Models and the Portfolio Effect](https://www.casact.org/abstract/dependence-models-and-portfolio-effect)
- [Capital Adequacy and Allocation Using Dynamic Financial Analysis](https://www.casact.org/abstract/capital-adequacy-and-allocation-using-dynamic-financial-analysis)
- [Two Alternative Methods for Calculating the Unallocated Loss Adjustment Expense Reserve](https://www.casact.org/abstract/two-alternative-methods-calculating-unallocated-loss-adjustment-expense-reserve)
- [Risk Load and the Default Rate of Surplus](https://www.casact.org/abstract/risk-load-and-default-rate-surplus)
- [Random Number Generation Using Low Discrepancy Points](https://www.casact.org/abstract/random-number-generation-using-low-discrepancy-points)
- [The Concentration Charge: Reflecting Catastrophe Exposure Accumulation in Rates](https://www.casact.org/abstract/concentration-charge-reflecting-catastrophe-exposure-accumulation-rates)
- [An Application of Game Theory: Property Catastrophe Risk Load](https://www.casact.org/abstract/application-game-theory-property-catastrophe-risk-load-0)
